/*Dofile for Crowley-Song Solar Panels*/ 
/*By Meredith A Crowley, 22 September 2015, Revised February 2019 */
/*Datafile: Cross-section of CARs and firm attributes compiled by H. Song */


clear

/*pathname for  directory*/
cd <<INSERT THE PATH HERE>>

*********************************************************************
*Cross-sectional regressions for JJIE Revision*
*********************************************************************
/*Note that the esttab command requires clear memory in order to only pick up 
the relevant estimation columns */ 
clear all

****************************************************************
/*Table 6: Cross-sectional variation in the CAR - export share*/ 
****************************************************************
/*Because HK does not have export data available, this is estimated on US and CN*/
 
clear all

sysuse cross_section_CN_HK_US_cln.dta   
   
reg MVRM7_ADfile  ex_share 
reg MVRM7_prelim  ex_share 
reg MVRM7_devplan  ex_share 
reg MVRM7_amend  ex_share 
reg MVRM7_subsidy  ex_share 
reg MVRM7_final  ex_share 

   


****************************************************************
/*Table 7: Cross-sectional variation in the CAR - labor prod'y */ 
****************************************************************
clear all
sysuse cross_section_CN_HK_US_cln.dta    
   
reg MVRM7_ADfile ln_lab_prody   soe_lab_prody
reg MVRM7_prelim ln_lab_prody  soe_lab_prody
reg MVRM7_devplan ln_lab_prody  soe_lab_prody
reg MVRM7_amend ln_lab_prody  soe_lab_prody
reg MVRM7_subsidy ln_lab_prody   soe_lab_prody
reg MVRM7_final ln_lab_prody  soe_lab_prody 




****************************************************************
/*Table 8: Cross-sectional variation in the CAR - op costs/sales */ 
****************************************************************
clear all

sysuse cross_section_CN_HK_US_cln.dta    
   
reg MVRM7_ADfile cost_sales cost_soe
reg MVRM7_prelim cost_sales cost_soe
reg MVRM7_devplan cost_sales cost_soe
reg MVRM7_amend cost_sales cost_soe
reg MVRM7_subsidy cost_sales cost_soe
reg MVRM7_final cost_sales cost_soe 


   
****************************************************************
/*Table 9: Cross-sectional variation in the CAR - petition  */ 
****************************************************************
*/clear all

sysuse cross_section_CN_HK_US_cln.dta 


reg CAR7_ADfile ln_em  leverage
reg CAR7_ADfile ln_em RD_sales
reg CAR7_ADfile ln_em soe
ivregress 2sls CAR7_ADfile ln_em (USlist = foreign_edu)
reg CAR7_ADfile ln_em WCM
   
*Run a specification that returns first stage F-Stat
ivreg2 CAR7_ADfile ln_em (USlist = foreign_edu),ffirst


****************************************************************
/*Table 10: Cross-sectional variation in the CAR - SOE effect  */ 
****************************************************************

clear all
sysuse cross_section_CN_HK_US_cln.dta 


reg CAR7_ADfile    soe ln_em
reg CAR7_prelim   soe ln_em
reg CAR7_devplan   soe ln_em
reg CAR7_amend   soe ln_em
reg CAR7_subsidy   soe ln_em 
reg CAR7_final   soe ln_em
 
********************************************************************************
/*Table 11: Cross-sectional variation in the CAR - Listing market effect - IV */ 
********************************************************************************
clear all

sysuse cross_section_CN_HK_US_cln.dta 

  
 *Do first stage weak instrument test following Stock and Yogo - use ivreg2 with ffirst to obtain first stage F-stat 

ivreg2 CAR7_ADfile ln_em (USlist = foreign_edu),ffirst
ivreg2 CAR7_prelim ln_em (USlist = foreign_edu),ffirst
ivreg2  CAR7_devplan ln_em (USlist = foreign_edu),ffirst
ivreg2  CAR7_amend ln_em (USlist = foreign_edu),ffirst
ivreg2  CAR7_subsidy ln_em (USlist = foreign_edu),ffirst
ivreg2 CAR7_final ln_em (USlist = foreign_edu),ffirst



